==> opennms-services-1.8.4-sources.jar: org/opennms/netmgt/vulnscand/DescrValues.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.netmgt.vulnscand;

import org.opennms.netmgt.EventConstants;

/**
 * Class that holds the return values when parsing a description field from
 * Nessus.
 *
 * @author ranger
 * @version $Id: $
 */
public class DescrValues {
    String descr;

    String cveEntry;

    int severity;

    /**
     * <p>Constructor for DescrValues.</p>
     */
    public DescrValues() {
        descr = null;
        cveEntry = null;
        severity = -1;
    }

    /**
     * <p>useDefaults</p>
     */
    public void useDefaults() {
        descr = "";
        severity = EventConstants.SEV_INDETERMINATE;
    }

    /**
     * <p>isValid</p>
     *
     * @return a boolean.
     */
    public boolean isValid() {
        if ((descr != null) && (severity > 0))
            return true;
        else
            return false;
    }

    /**
     * <p>toString</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String toString() {
        return ("descr: " + descr + "\ncveEntry: " + cveEntry + "\nseverity: " + severity + "\n");
    }
}

==> opennms-services-1.8.12-sources.jar: org/opennms/netmgt/vulnscand/DescrValues.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.netmgt.vulnscand;

import org.opennms.netmgt.model.OnmsSeverity;

/**
 * Class that holds the return values when parsing a description field from
 * Nessus.
 *
 * @author ranger
 * @version $Id: $
 */
public class DescrValues {
    String descr;

    String cveEntry;

    int severity;

    /**
     * <p>Constructor for DescrValues.</p>
     */
    public DescrValues() {
        descr = null;
        cveEntry = null;
        severity = -1;
    }

    /**
     * <p>useDefaults</p>
     */
    public void useDefaults() {
        descr = "";
        severity = OnmsSeverity.INDETERMINATE.getId();
    }

    /**
     * <p>isValid</p>
     *
     * @return a boolean.
     */
    public boolean isValid() {
        if ((descr != null) && (severity > 0))
            return true;
        else
            return false;
    }

    /**
     * <p>toString</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String toString() {
        return ("descr: " + descr + "\ncveEntry: " + cveEntry + "\nseverity: " + severity + "\n");
    }
}
